@@ -276,7 +276,7 @@ class WSGIRequest(object):
         msg += '\nscheme=%s, host=%s, script_name=%s, path_info=%s,' % \
             (pf(self.scheme), pf(self.host), pf(self.script_name),
              pf(self.path_info))
-        msg += '\nlanguges=%s,' % pf(self.languages)
+        msg += '\nlanguages=%s,' % pf(self.languages)
         if self.charset:
             msg += ' charset=%s, errors=%s,' % (pf(self.charset),
                                                 pf(self.errors))
@@ -337,7 +337,7 @@ class WSGIResponse(object):
         
         Example usage:
         
-        .. code-block:: Python
+        .. code-block:: python
 
             def wsgi_app(environ, start_response):
                 response = WSGIResponse()
@@ -398,7 +398,7 @@ class WSGIResponse(object):
         if path is not None:
             self.cookies[key]['path'] = path
         if domain is not None:
-            self.cookies[key]['domain'] = path
+            self.cookies[key]['domain'] = domain
         self.cookies[key]['expires'] = 0
         self.cookies[key]['max-age'] = 0
 
